#!/usr/bin/env python3

import discord
import emoji
import pendulum

from discord import app_commands
from discord.utils import get
from src.logs import Log
from src.settings import Settings
from src.sql.controllers.biketag_user import BiketagUser
from src.sql.controllers.biketag_users import BiketagUsers


log = Log("main")
settings = Settings().get_config()

intents = discord.Intents.default()
intents.message_content = True
intents.reactions = True
# intents.members = True
# bot = commands.Bot(command_prefix="!", intents=intents)

# client = discord.Client(intents=intents, application_id=1138055850766897223)
# tree = app_commands.CommandTree(client)


class DiscordClient(discord.Client):
    def __init__(self):
        super().__init__(
            intents=discord.Intents.all(), application_id=settings["discord"]["app_id"]
        )
        self.synced = False

    async def on_ready(self):
        await self.wait_until_ready()
        if not self.synced:
            await tree.sync(guild=discord.Object(id=settings["discord"]["guild_id"]))
            self.synced = True


client = DiscordClient()
tree = app_commands.CommandTree(client)


# Add the guild ids in which the slash command will appear. If it should be in all, remove the argument, but note that it will take some time (up to an hour) to register the command if it's for all guilds.
@tree.command(
    name="biketag",
    description="Les points du mois en cours",
    guild=discord.Object(id=settings["discord"]["guild_id"]),
)
async def biketag_list(interaction: discord.Interaction):
    # for user in board:
    description = ""
    count = 1
    for user in BiketagUsers.get_users():
        biketag_user = get(client.get_all_members(), id=user.id)
        str_emoji = [
            "null",
            emoji.emojize(":crown:"),
            emoji.emojize(":second_place:"),
            emoji.emojize(":third_place:"),
        ]
        description += f"**{str_emoji[count] if count < 4 else count}** {biketag_user.mention} | Point{'s' if user.point > 1 else ''} : {user.point} \n"
        count += 1

    description += emoji.emojize("\nÀ vos bicyclettes :bike: !")
    embedMessage = discord.Embed(
        color=0x00FF00,
        title="Les points du mois en cours !",
        description=description,
    )

    await interaction.response.send_message(embed=embedMessage)


@tree.command(
    name="biketag_point",
    description="Ajout d'un point à un membre",
    guild=discord.Object(id=settings["discord"]["guild_id"]),
)
@app_commands.describe(member="Le biketageur qui reçoit le point")
async def biketag_givepoint(interaction: discord.Interaction, member: discord.Member):
    if member.id == interaction.user.id:
        await interaction.response.send_message(
            emoji.emojize(
                f"<@{interaction.user.id}> a tenté de s'auto attribué un point (mais n'a pas réussi :smirk:) "
            )
        )
    else:
        biketag_user = BiketagUser(id=member.id, guild_id=interaction.guild_id)
        if biketag_user.is_registered():
            biketag_user.get()
            biketag_user.add_point()
            await interaction.response.send_message(
                f"Bravo <@{member.id}> pour avoir trouvé un tag. Tu as donc {biketag_user.point} point{'s' if biketag_user.point > 1 else ''}."
            )
        else:
            if biketag_user.register():
                log.info(f"User {member.id} is now registered")
                biketag_user.get()
                biketag_user.add_point()
                await interaction.response.send_message(
                    f"Bravo <@{member.id}> pour avoir trouvé un tag. Tu as donc {biketag_user.point} point{'s' if biketag_user.point > 1 else ''}."
                )
            else:
                log.error(f"Cannot register {member.id}")
                await interaction.response.send_message(
                    f"Impossible d'ajouter <@{member.id}> dans la liste des participants"
                )
                await interaction.followup.send("Essaye en tapant dessus puis dessous")

        # await interaction.followup.send(f"Hello! <@{interaction.user.id}>")


@tree.command(
    name="biketag_reset",
    description="Réinitialise les points du mois en cours",
    guild=discord.Object(id=settings["discord"]["guild_id"]),
)
async def biketag_reset(interaction: discord.Interaction):
    biketagers = BiketagUsers.get_users()
    if len(biketagers) > 0:
        first_biketager = biketagers[0]
        now = pendulum.now()
        roles = []
        for role in interaction.user.roles:
            roles.append(role.name)
        print(roles)
        if (now.day != 6 and now.hour < 18) and "Admin" not in roles:
            await interaction.response.send_message(
                emoji.emojize(
                    f"<@{interaction.user.id}> a tenté de réinitialiser les points en dehors de l'Apérou pour, peut être, avoir la victoire (mais n'a pas réussi :smirk:) :police_officer: \n Une tournée générale pour se faire pardonner ? :innocent: "
                )
            )
        else:
            BiketagUsers.drop_all_users()
            await interaction.response.send_message(
                emoji.emojize(
                    f":trophy: <@{first_biketager.id}> a gagné-e avec {first_biketager.point} point{'s' if first_biketager.point > 1 else ''} ! :trophy: \nL'heure est au nouveau mois, à vos vélos ! "
                )
            )
    else:
        await interaction.response.send_message("Un autre reset a déjà été effectué")


client.run(token=settings["discord"]["token"])
