from src.logs import Log
from os import path

log = Log("settings")


class Settings:
    def get_config(self):
        if path.exists("config.yml"):
            import yaml

            log.info("Found config.yml. Load it")
            with open("config.yml", "r") as yamlfile:
                config = yaml.load(yamlfile, Loader=yaml.FullLoader)
                log.info("Config read successful")
        else:
            log.warning("Config file not found, fallback to environment var")
            from dotenv import load_dotenv
            from os import environ, getenv

            load_dotenv()
            if "DB_HOST" not in environ:
                log.critical("DB_HOST environment variable don't exist")
            if "DB_PORT" not in environ:
                log.critical("DB_PORT environment variable don't exist")
            if "DB_NAME" not in environ:
                log.critical("DB_NAME environment variable don't exist")
            if "DB_USER" not in environ:
                log.critical("DB_USER environment variable don't exist")
            if "DB_PASS" not in environ:
                log.critical("DB_PASS environment variable don't exist")
            if "DISCORD_TOKEN" not in environ:
                log.critical("DISCORD_TOKEN environment variable don't exist")
            if "DISCORD_APP_ID" not in environ:
                log.critical("DISCORD_APP_ID environment variable don't exist")
            if "DISCORD_GUILD_ID" not in environ:
                log.critical("DISCORD_GUILD_ID environment variable don't exist")
            config = {
                "db": {
                    "host": getenv("DB_HOST"),
                    "port": getenv("DB_PORT"),
                    "dbname": getenv("DB_NAME"),
                    "user": getenv("DB_USER"),
                    "password": getenv("DB_PASS"),
                },
                "discord": {
                    "token": getenv("DISCORD_TOKEN"),
                    "app_id": getenv("DISCORD_APP_ID"),
                    "guild_id": getenv("DISCORD_GUILD_ID"),
                },
            }
        return config
