
from src.sql.cruds.guild import guildCrud
from src.sql.models.guild import guildBase
from src.logs import Log
from src.settings import Settings


log = Log("controllers_guild")
config = Settings().get_config()


class Guild(object):
    def __init__(self, guild_id, channel_id):
        self.guild_id = guild_id
        self.channel_id = channel_id
        return

    def get(self):
        return guildBase(guild_id=self.guild_id, channel_id=self.channel_id)

    @staticmethod
    def get_all_guilds():
        guilds = guildCrud.get_guilds()
        guild_return = []
        for guild in list(guilds):
            guild_return.append(Guild(guild["guild_id"], guild["channel_id"]))
        return guild_return

    def is_guild_registered(self):
        guild = guildBase(guild_id=self.guild_id, channel_id=self.channel_id)
        if list(guildCrud.get_guild(guild)):
            return True
        else:
            log.error(f"This guild ({self.guild_id}) doesn't exist.")
            return False

    def is_in_configured_room(self):
        return self.is_guild_registered()

    def register(self):
        guild = guildBase(guild_id=self.guild_id, channel_id=self.channel_id)
        request = guildCrud.create_guild(guild)
        if request["inserted"] > 0:
            log.info(f"Guild {self.guild_id} registered")
        else:
            log.error(f"An error occured to register guild {self.guild_id}")
        return

    def update(self):
        guild = guildBase(guild_id=self.guild_id, channel_id=self.channel_id)
        request = guildCrud.update_guild(guild)
        if request["replaced"] > 0:
            log.info(f"Guild {self.guild_id} was correctly updated")
        else:
            log.error(f"An error occured on guild {self.guild_id} update")
        return

    def delete(self):
        guild = guildBase(guild_id=self.guild_id, channel_id=self.channel_id)
        request = guildCrud.delete_guild(guild)
        if request["deleted"] > 0:
            log.info(f"Guild {self.guild_id} was correctly remove")
        else:
            log.error(f"An error occured on guild {self.guild_id} deletion")
        return
