from src.logs import Log
from src.settings import Settings
from src.sql.models.biketag_user import BiketagUserBase, BiketagUserModel
from src.sql.schemas.biketag_user import BiketagUser
from src.sql.database import SessionLocalRo, SessionLocalRw
from sqlalchemy import desc, text

log = Log("crud_BiketagUser")
config = Settings().get_config()


class BikeTagUserCrud:
    @staticmethod
    def get_user_by_id(user_id: int):
        """get_user_by_id.

        :param user_id:
        :type user_id: int
        """
        with SessionLocalRo() as session:
            return session.query(BiketagUser).filter(id == user_id).first()
        return user

    @staticmethod
    def get_all_users():
        """get_all_users"""
        with SessionLocalRo() as session:
            return session.query(BiketagUser).order_by(desc("point")).all()

    @staticmethod
    def get_user(user: BiketagUserBase):
        """get_user.

        :param user:
        :type user: BiketagUserBase
        """
        with SessionLocalRo() as session:
            return session.query(BiketagUser).filter(BiketagUser.id == user.id).first()
        return None

    @staticmethod
    def get_users():
        return user

    @staticmethod
    def create_user(user: BiketagUserBase):
        user_schema = BiketagUser(id=user.id, guild_id=user.guild_id)
        with SessionLocalRw() as session:
            session.add(user_schema)
            session.commit()
        return True

    @staticmethod
    def update_user(user: BiketagUserModel):
        with SessionLocalRw() as session:
            biketag_user = (
                session.query(BiketagUser).filter(BiketagUser.id == user.id).first()
            )
            biketag_user.point = user.point
            session.commit()
            session.refresh(biketag_user)
            return biketag_user
        return

    @staticmethod
    def delete_user(user: BiketagUserBase):
        return user

    @staticmethod
    def truncate_user():
        with SessionLocalRw() as session:
            session.execute(text("""TRUNCATE TABLE biketag_user;"""))
            session.commit()
        return
